==> tfx-cli-0.1.2.tgz: package/exec/build-show.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var cmdm = require('../lib/tfcommand');
var buildifm = require('vso-node-api/interfaces/BuildInterfaces');
var params = require('../lib/parameternames');
function describe() {
    return 'get a build';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([params.PROJECT_NAME, params.GENERIC_ID], []);
}
exports.getArguments = getArguments;
function getCommand() {
    // this just offers description for help and to offer sub commands
    return new BuildGetSingle;
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = true;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var BuildGetSingle = (function (_super) {
    __extends(BuildGetSingle, _super);
    function BuildGetSingle() {
        _super.apply(this, arguments);
    }
    BuildGetSingle.prototype.exec = function (args, options) {
        var buildapi = this.getWebApi().getQBuildApi();
        var project = args[0] || options[params.PROJECT_NAME];
        this.checkRequiredParameter(project, params.PROJECT_NAME, params.PROJECT_FRIENDLY_NAME);
        var buildId = +args[1] || +options[params.GENERIC_ID];
        this.checkRequiredParameter(buildId, params.GENERIC_ID, params.BUILD_ID);
        return buildapi.getBuild(buildId, project);
    };
    BuildGetSingle.prototype.output = function (data) {
        if (!data) {
            throw new Error('no build supplied');
        }
        var build = data;
        console.log();
        console.log('id   : ' + build.id);
        console.log('definition name: ' + build.definition.name);
        console.log('requested by : ' + build.requestedBy.displayName);
        console.log('status : ' + buildifm.BuildStatus[build.status]);
        console.log('queue time : ' + build.queueTime);
    };
    return BuildGetSingle;
})(cmdm.TfCommand);
exports.BuildGetSingle = BuildGetSingle;

==> tfx-cli-0.1.6.tgz: package/exec/build-show.js <==
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var cmdm = require('../lib/tfcommand');
var buildifm = require('vso-node-api/interfaces/BuildInterfaces');
var params = require('../lib/parameternames');
var trace = require('../lib/trace');
function describe() {
    return 'get a build';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([params.PROJECT_NAME, params.GENERIC_ID], []);
}
exports.getArguments = getArguments;
function getCommand() {
    // this just offers description for help and to offer sub commands
    return new BuildShow;
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = true;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var BuildShow = (function (_super) {
    __extends(BuildShow, _super);
    function BuildShow() {
        _super.apply(this, arguments);
    }
    BuildShow.prototype.exec = function (args, options) {
        trace('build-show.exec');
        var buildapi = this.getWebApi().getQBuildApi();
        var project = args[0] || options[params.PROJECT_NAME];
        this.checkRequiredParameter(project, params.PROJECT_NAME, params.PROJECT_FRIENDLY_NAME);
        var buildId = +args[1] || +options[params.GENERIC_ID];
        this.checkRequiredParameter(buildId, params.GENERIC_ID, params.BUILD_ID);
        return buildapi.getBuild(buildId, project);
    };
    BuildShow.prototype.output = function (data) {
        if (!data) {
            throw new Error('no build supplied');
        }
        var build = data;
        console.log();
        console.log('id   : ' + build.id);
        console.log('definition name: ' + build.definition.name);
        console.log('requested by : ' + build.requestedBy.displayName);
        console.log('status : ' + buildifm.BuildStatus[build.status]);
        console.log('queue time : ' + build.queueTime);
    };
    return BuildShow;
})(cmdm.TfCommand);
exports.BuildShow = BuildShow;
